import os
import sys
import shutil
import platform
from py_compile import compile
# 1. 先将文件编译成pyc文件:在cmd中，指定到pyc_create.py的路径下：python pyc_create compile  需要编译的文件的根路径；这样就可以将要编译的文件编译成pyc文件了，但是文件都存在各个文件夹的__pycache__中
# 2. 将__pycache__中的pyc文件拷贝到原来py存在的位置：python pyc_create copy  文件的根路径；这样就将编译的文件存在原来py文件的位置了
# 3. 将原来的py文件删掉就可以了：python pyc_create remove 文件根路径
# 4. 将文件的名字进行更改，我这里使用的是pyhon 3.5版本的，所以文件的名字变成了*.cpython-35.pyc,要将其中的cpython-35去掉，不然不能正常运行，因为文件的名字默认最后一个后缀是扩展名，其他的为文件名字
# 5. 执行完毕，就可以使用了。


class Obfuscate(object):

    def __init__(self):
        arr = platform.python_version().replace('.', '')
        self.cpython_version = 'cpython-{}'.format(arr[:2])

    def _print(self, msg):
        if self.is_debug:
            print(msg)

    def execute(self, comd, parent, cfile):
        fullname = os.path.join(parent, cfile)

        if comd == 'clean' and cfile[-4:] == '.pyc':
            try:
                os.remove(fullname)
                self._print("Success remove file:%s" % fullname)
            except:
                self._print("Can't remove file:%s" % fullname)
        # 在这里将找到的py文件进行编译成pyc，但是会指定到一个叫做__pycache__的文件夹中
        if comd == 'compile' and cfile[-3:] == '.py':
            try:
                compile(fullname)
                self._print("Success compile file:%s" % fullname)
            except:
                self._print("Can't compile file:%s" % fullname)
        if comd == 'remove' and cfile[-3:] == '.py' and cfile != 'settings.py' and cfile != 'wsgi.py':
            try:
                os.remove(fullname)
                self._print("Success remove file:%s" % fullname)
            except:
                self._print("Can't remove file:%s" % fullname)
        if comd == 'copy' and cfile[-4:] == '.pyc':
            shutil.copy(fullname, os.path.dirname(os.path.dirname(fullname)))
            self._print('update the dir of file successfully')
        if comd == 'cpython' and cfile[-4:] == '.pyc':
            cfile_name = ''
            cfile_list = cfile.split('.')
            for i in range(len(cfile_list)):
                if cfile_list[i] == self.cpython_version:
                    continue
                cfile_name += cfile_list[i]
                if i == len(cfile_list) - 1:
                    continue
                cfile_name += '.'
            shutil.move(fullname, os.path.join(parent, cfile_name))
            self._print('update the name of the file successfully')

    def run(self):
        if len(sys.argv) >= 3:
            entry = sys.argv[0]
            comd = sys.argv[1]  # 输入的命令
            path = sys.argv[2]  # 目录文件的地址
            ignorelist = []
            self.is_debug = os.getenv('is_debug')
            if len(sys.argv) >= 5 and sys.argv[3] == '--ignore':
                ignorelist = sys.argv[4:]
            if os.path.exists(path) and os.path.isdir(path):
                for parent, dirname, filename in os.walk(path):
                    if parent.replace('./', '').split('\\')[0] not in ignorelist:
                        for cfile in filter(lambda x: x != entry, filename):
                            self.execute(comd, parent, cfile)
            else:
                print("Not an directory or Direcotry doesn't exist!", path)
        else:
            print("Usage:")
            print("\tpython compile_pyc.py clean PATH\t\t#To clean all pyc files")
            print("\tpython compile_pyc.py compile PATH\t\t#To generate pyc files")
            print("\tpython compile_pyc.py remove PATH\t\t#To remove py files")


if __name__ == '__main__':
    Obfuscate().run()



import os
import math
import json
import random
import string
import requests
from io import BytesIO
class DPResponse(object):
    ok = False
    text = None

    def __init__(self, ok, text):
        self.ok = ok
        self.text = text


class Uploader(object):
    r"""
    params:file_name 物理文件路径  
    params:data 合并文件接口附带的参数,数据集相关参数  
    """
    def __init__(self, file_name, data, **args):
        r"""
        params:file_name 物理文件路径  
        params:data 合并文件接口附带的参数,数据集相关参数  
        params:args 上传接口upload_url
        """
        if not os.path.exists(file_name):
            raise Exception('File not exist!')

        self._upload_url = args.get('upload_url')

        if not self._upload_url:
            raise Exception('upload_url is required')
        
        _jwt_token = args.get('jwt_token')

        self._headers = None
        if _jwt_token:
          self._headers = {'Authorization': _jwt_token}
        
        self._file_name = file_name
        # 文件校验
        if not os.path.exists(self._file_name):
            raise Exception('file:{} not found!'.format(self._file_name))
        self._data = data

    def start(self):
        try:
            self._reset_task_id()
            self._push_part_file()
            return DPResponse(True, self.text)
        except Exception as err:
            return DPResponse(False, str(err))

    def _reset_task_id(self):
        self.task_id = 'wu_{}'.format(
            ''.join(random.sample(string.ascii_letters + string.digits, 28)))

    # slice
    def _push_part_file(self):
        
        _chunk_size = 20 * 1024 * 1024
        _totalChunks = math.ceil(os.path.getsize(self._file_name) / _chunk_size)

        with open(self._file_name, 'rb') as f:
            _chunk = 1

            while True:
                _data = {}
                part_bytes = f.read(_chunk_size)
                if not part_bytes:
                    break
                files = {'file': (self.task_id, BytesIO(part_bytes), 'application')}
                _data['task_id'] = self.task_id
                _data['chunkNumber'] = _chunk
                _data['totalChunks'] = _totalChunks

                _res = requests.post(self._upload_url, files=files, data=dict(_data, **self._data), headers=self._headers)
                if not _res.ok:
                    raise Exception('Encountered an error in pushing a slice, {}'.format(_res.text))
                _chunk += 1
            
            self.text = _res.text
